# lokstats package

This is an package for advanced statistical calculations . 
It is having two functions 
1.) mulcor(dataframe_name,"column_name ")
	To calculate the multiple correlations it is used,here column name is the name of the column for which we want to calculate the multiple correlation.
2.) partcor(dataframe_name,"column1_name ","column1_name ")
	To calculate the Partial correlations it is used,here column1_name,column2_name are the names of the columns for which we want to calculate the partial correlation.
To see the full working go here:https://github.com/loksundar/partial_multiple_correlation
thank you